@@ -103,6 +103,7 @@ fn path_from_input(
     base_path: &Path, // either the selected path or the root path
     input_arg: Option<&String>,
     app_state: &AppState,
+    con: &AppContext,
 ) -> PathBuf {
     match (input_arg, internal_exec.arg.as_ref()) {
         (Some(input_arg), Some(verb_arg)) => {
@@ -119,7 +120,7 @@ fn path_from_input(
                 app_state,
                 Some(input_arg),
             );
-            path_builder.path(verb_arg)
+            path_builder.path(verb_arg, con)
         }
         (Some(input_arg), None) => {
             // the verb defines nothing
@@ -142,7 +143,7 @@ fn path_from_input(
                 app_state,
                 None,
             );
-            path_builder.path(verb_arg)
+            path_builder.path(verb_arg, con)
         }
         (None, None) => {
             // user only wants to open the selected path, either in the same panel or
@@ -158,6 +159,7 @@ pub fn get_status_markdown(
     sel_info: SelInfo<'_>,
     invocation: &VerbInvocation,
     app_state: &AppState,
+    con: &AppContext,
 ) -> String {
     let base_path = sel_info
         .one_path()
@@ -168,6 +170,7 @@ pub fn get_status_markdown(
         base_path,
         invocation.args.as_ref(),
         app_state,
+        con,
     );
     format!("Hit *enter* to focus `{}`", path.to_string_lossy())
 }
@@ -198,6 +201,7 @@ pub fn on_internal(
                 selected_path,
                 input_arg,
                 app_state,
+                cc.app.con,
             );
             on_path(path, screen, tree_options, bang, con)
         }
@@ -206,10 +210,14 @@ pub fn on_internal(
             if let Some(arg) = &internal_exec.arg {
                 // the internal_execution specifies the path to use
                 // (it may come from a configured verb whose execution is
-                //  `:focus some/path`).
+                //  `:focus some/path` or `:focus {initial-root}̀).
                 // The given path may be relative hence the need for the
                 // state's selection
-                let path = path::path_from(selected_path, PathAnchor::Unspecified, arg);
+                let path_builder = ExecutionStringBuilder::without_invocation(
+                    SelInfo::from_path(selected_path),
+                    app_state,
+                );
+                let path = path_builder.path(arg, con);
                 let bang = input_invocation
                     .map(|inv| inv.bang)
                     .unwrap_or(internal_exec.bang);
